@@ -2,7 +2,6 @@ local prefix = KEYS[1]
 local db_table = ARGV[1]
 local obj = cjson.decode(ARGV[2])
 
-
 -- Utility functions
 local conj_cache_key = function (db_table, scheme, obj)
     local parts = {}
@@ -34,7 +33,7 @@ if next(conj_keys) ~= nil then
     local cache_keys = redis.call('sunion', unpack(conj_keys))
     -- we delete cache keys since they are invalid
     -- and conj keys as they will refer only deleted keys
-    redis.call('del', unpack(conj_keys))
+    redis.call("unlink", unpack(conj_keys))
     if next(cache_keys) ~= nil then
         -- NOTE: can't just do redis.call('del', unpack(...)) cause there is limit on number
         --       of return values in lua.
